************
* SCRIPT: 1_process_fem_data.do
* PURPOSE: process data obtained from the Future Elderly Model
************

* Preamble (unnecessary when executing run.do)
run "$Longevity/scripts/programs/_config.do"

************
* Code begins
************

clear all
set more off

local fem_data "$Longevity/data/fem/no_inflation_or_mort_decline"

***
* Transition probabilities
***
use "`fem_data'/baseline_cohort_health_1yr.dta", clear
ren l2health health_state
rename phealth*_1yr phealth*
drop if age>100

* Correct rounding error issues #1: can only transition to higher-numbered states
qui forval x = 2/20 {
	forval y = 1/`=`x'-1' {			
		assert abs(phealth`y')<0.00001 if health_state==`x'
		replace    phealth`y'=0        if health_state==`x'
	}
}

* Correct rounding error issues #2: can only transition to states with same or greater number of chronic conditions
gen     num_cc = 1 if inlist(health_state,2,7,12,17)
replace num_cc = 2 if inlist(health_state,3,8,13,18)  & mi(num_cc)
replace num_cc = 3 if inlist(health_state,4,9,14,19)  & mi(num_cc)
replace num_cc = 4 if inlist(health_state,5,10,15,20) & mi(num_cc)
replace num_cc = 0 if mi(num_cc)

levelsof health_state if num_cc==0, local(states)
foreach s of local states {
	assert abs(phealth`s')<0.00000001 if inlist(num_cc,1,2,3,4)
	replace    phealth`s'=0           if inlist(num_cc,1,2,3,4)
}

levelsof health_state if num_cc==1, local(states)
foreach s of local states {
	assert abs(phealth`s')<0.00000001 if inlist(num_cc,2,3,4)
	replace    phealth`s'=0           if inlist(num_cc,2,3,4)
}

levelsof health_state if num_cc==2, local(states)
foreach s of local states {
	assert abs(phealth`s')<0.00000001 if inlist(num_cc,3,4)
	replace    phealth`s'=0           if inlist(num_cc,3,4)
}		

levelsof health_state if num_cc==3, local(states)
foreach s of local states {
	assert abs(phealth`s')<0.000001 if inlist(num_cc,4)
	replace    phealth`s'=0          if inlist(num_cc,4)
}

* Correction factor for a small number of probabilities that don't always quite sum to 1
egen tmp = rowtotal(phealth*)
gen correction = 1/tmp		

* fem transition probabilities start at age 51, so use age 51 data for age 50
sort health_state age
foreach v of varlist phealth* {
	replace `v' = `v'[_n+1] if age==50
	assert inrange(`v',0,1)
}
drop tmp correction num_cc

* Ensure probabilities sum to 1 for all ages
egen tmp = rowtotal(phealth*)
assert abs(tmp-1)<0.000002
drop tmp
sort health_state age
outsheet using "$Longevity/processed/baseline_cohort_transitions.csv", comma nol replace


***
* Baseline interest rate (no medical spending or income shocks) is 3%
***
ren p* r*
foreach v of varlist r* {
	replace `v' = 0.03
}
sort health_state age
outsheet using "$Longevity/processed/returns_baseline.csv", comma nol replace

***
* EQ-5D (quality of life)
***
use "`fem_data'/baseline_cohort_eq5d_1yr.dta", clear
ren l2health health_state
ren eq5d quality
drop if age>100

assert inrange(quality,0,1)
sort health_state age
outsheet using "$Longevity/processed/baseline_cohort_quality.csv", comma nol replace

replace quality = 1
outsheet using "$Longevity/processed/baseline_cohort_quality_constant.csv", comma nol replace

***
* Mortality rates
***
use "`fem_data'/baseline_cohort_mort_1yr.dta", clear
ren l2health health_state
ren pdied_1yr pdied
drop if age>100

* FEM mortality probabilities start at age 51, so use age 51 data for age 50
bysort health_state (age): replace pdied = pdied[_n+1] if age==50

* Set mortality equal to 100% at age 100 (max age in model)
replace pdied = 1 if age==100

assert inrange(pdied,0,1)
sort health_state age
outsheet using "$Longevity/processed/baseline_cohort_mortality.csv", comma nol replace
	
	
***
* Bequest motive parameter
***
gen bequest = 1.2
sort health_state age bequest
order age health_state bequest		
outsheet using "$Longevity/processed/baseline_cohort_bequest.csv", comma replace nol


**********************************
* Distribution of initial states
**********************************
use "$Longevity/data/fem/healthstate_age50.dta", clear
ren l2health health_state
outsheet using "$Longevity/processed/population_age50.csv", comma replace nol


**********************************
* Produce interest rate returns
*   - Equal to 3%, minus medical spending and income shocks
**********************************

* FEM earnings (2010 dollars) by state and age. Add Social Security income to this
*   - average social security in Dec 2010 was $1261.62 per month ($15,139 per year) for retired workers https://www.ssa.gov/OACT/ProgData/icp.html 
*   - average claiming age is 65
use "$Longevity/data/fem/baseline_cohort_iearnx_1yr.dta", clear
drop if age>100
assert inrange(age,50,100)

replace iearnx = iearnx + 15.1 if age>=65

ren l2health health_state
ren iearnx income
assert !mi(income)
outsheet using "$Longevity/processed/income.csv", comma replace nol

keep if age==50
keep health_state income
ren income wealth
outsheet using "$Longevity/processed/income_age50.csv", comma replace nol

* Calculate expected present value of income, by age and state
local income_epv_outputfile "$Longevity/processed/income_epv.csv"
rscript using "$Longevity/scripts/programs/model-baseline/income_epv.R", args("$Longevity" "`income_epv_outputfile'" "$Longevity/processed/baseline_cohort_mortality.csv" "$Longevity/processed/baseline_cohort_transitions.csv" "$Longevity/processed/income.csv")

* This program computes sum of squared error for two given interest rate files
program define converge_check, rclass
	
	args r1 r2
	tempfile returns1
	
	insheet using "`r1'", clear
	ren rhealth* r1_rhealth*
	save "`returns1'", replace
	
	insheet using "`r2'", clear
	ren rhealth* r2_rhealth*
	merge 1:1 health_state age using "`returns1'", assert(match) nogenerate
	
	forval x = 1/20 {
		gen double diff = abs(r1_rhealth`x' - r2_rhealth`x')^2
		egen double sum`x' = sum(diff)
		drop diff
	}
	egen total_sum = rowtotal(sum*)
	
	summ total_sum
	assert abs(r(sd)) < 0.0001
	noi di r(mean)
	return local sqerror =  r(mean)
end

***
* Medical spending and income shocks are normalized by wealth 
*   1. Estimate wealth by age and state, in setting with r=3% (ie no spending or wealth shocks) and baseline VSL of $6.8 million
*   2. Calculate new interest rates using this wealth estimate
*   3. Repeat until there is convergence
***	
tempfile wealth_by_age_state_output medical_spending current_income_wealth future_income calibration_outputfile
local mort_base "$Longevity/processed/baseline_cohort_mortality.csv"
local qual_base "$Longevity/processed/baseline_cohort_quality.csv"
local trans_base "$Longevity/processed/baseline_cohort_transitions.csv"

* Smooth the spending data beginning at age 99, where it becomes noisy/missing for some states because of small cells
use "`fem_data'/baseline_cohort_oopmd_1yr.dta", clear
ren l2health health_state
drop if age>100
gen age2 = age*age
reg oopmd c.age##i.health_state c.age2#i.health_state if inrange(age,80,98)
predict yhat
replace oopmd = yhat if age>=99
drop yhat age2
assert !mi(oopmd)
save "$Longevity/processed/baseline_cohort_oopmd.dta", replace

* Estimate r(t,Y_t,Y_{t+1}) using spending, income, and wealth paths. Iterate until reaching fixed point where wealth paths are consistent with r(t,Y_t,Y_{t+1}).
local run_no = 0
local converged = 0
qui while `converged'==0 {

	if `run_no'==0 copy "$Longevity/processed/returns_baseline.csv"     "$Longevity/processed/returns_init.csv", replace
	else           copy "$Longevity/processed/returns_oopmd_income.csv" "$Longevity/processed/returns_init.csv", replace

	local rates_init "$Longevity/processed/returns_init.csv"

	* (1) Given target VSL of $6.8 million for state 1, calculate initial wealth in that state
	local target_vsl 6800000
	local gamma 1.25
	rscript using "$Longevity/scripts/programs/model-baseline/wealth_calibration_state1.R", args("`target_vsl'" "$Longevity" "`calibration_outputfile'" "`mort_base'" "`qual_base'" "`trans_base'" "`rates_init'" "`gamma'")
	insheet using "`calibration_outputfile'", comma clear
	noi tab x
	local initial_wealth = x	

	* (2) Given this initial wealth, calculate wealth for all possible states and ages
	rscript using "$Longevity/scripts/programs/model-baseline/wealth_by_age_state.R", args(`initial_wealth' "$Longevity" "`wealth_by_age_state_output'" "`mort_base'" "`qual_base'" "`trans_base'" "`rates_init'" `gamma')
	insheet using "`wealth_by_age_state_output'", clear

	* Replace zero's with neighboring values for ages 50 and 51
	foreach v in v2 v3 {
		egen max_`v' = max(`v')
		replace `v' = max_`v' if `v<'<0.01
		drop max_`v'
	}
	ren v1 health_state
	forval x = 2/52 {
		assert v`x'>1 & !mi(v`x')
		ren v`x' age`=48+`x''
	}
	reshape long age, i(health_state)
	ren age wealth
	ren _j age
	save "$Longevity/results/intermediate/wealth_by_age_state.dta", replace

	* Create file containing EPV and wealth, by current age and state
	insheet using "$Longevity/processed/income_epv.csv", clear
	ren v1 health_state
	forval x = 2/52 {
		ren v`x' age`=48+`x''
	}
	reshape long age, i(health_state)
	ren age income_epv
	ren _j age
	merge 1:1 health_state age using "$Longevity/results/intermediate/wealth_by_age_state.dta", assert(match) nogenerate
	save "`current_income_wealth'", replace

	* Create file containing EPV for possible transition states
	keep age health_state income_epv
	reshape wide income_epv, i(age) j(health_state)
	save "`future_income'", replace

	* Grab FEM medical spending and income data, normalize by wealth, and output implied interest rate
	use "$Longevity/processed/baseline_cohort_oopmd.dta", clear
	merge 1:1 age health_state using "`current_income_wealth'", assert(match) nogenerate
	merge m:1 age using "`future_income'", assert(match) nogenerate

	forval x = 1/20 {
		
		* Prohibit (small) posibility of positive income shock. (This has approximately 0 effect on estimates because these are associated with tiny transition probabilities.)
		gen delta_income_epv`x' = income_epv`x' - income_epv if health_state < `x'
		replace delta_income_epv`x' = 0 if mi(delta_income_epv`x')
		replace delta_income_epv`x' = 0 if delta_income_epv`x'>0	
		gen rhealth`x' = max(0.03 + ln(1 - oopmd/wealth + delta_income_epv`x'*1000/wealth),-.95)
	}
	sort health_state age
	outsheet age health_state rhealth* using "$Longevity/processed/returns_oopmd_income.csv", comma nol replace 

	local run_no = 1
	converge_check "`rates_init'" "$Longevity/processed/returns_oopmd_income.csv"
	noi di "Sum of squared errors: `r(sqerror)'"

	if `r(sqerror)' < 0.1 local converged = 1
}
	
** EOF
