************
* SCRIPT: 2_fem_analysis.do
* PURPOSE: caclulate consumption and VSL paths using the FEM data
************

* Preamble (unnecessary when executing run.do)
run "$Longevity/scripts/programs/_config.do"

************
* Code begins
************

clear all
program drop _all
set more off
set maxvar 51000
tempfile tmp_mort tmp_VSL tmp_path tmp_wealth tmp_population_age50 tmp

* Note: rates_alt not currently used
local mort      "$Longevity/processed/baseline_cohort_mortality.csv"
local trans     "$Longevity/processed/baseline_cohort_transitions.csv"
local rates_alt "$Longevity/processed/"

local population_age50 "$Longevity/processed/population_age50.csv"
local income_age50 "$Longevity/processed/income_age50.csv"


* nsims = total number of simulations
* target_vsl = population-weighted average VSL at age 50
local target_vsl 6000000
local num_sims 50000

***
* Function for processing output
***
mata:
real matrix reshape() {
	
	// Vars: sim, age, VSL/path
	my_mat = J(0,3,.)
	st_view(V=., ., .)
	
	nrows = rows(V)
	ncols = cols(V)
	
	for (i=2; i<=ncols; i++) {
		sim = J(nrows,1,i-1)
		my_mat = my_mat \ (sim,V[.,(1,i)])
	}
	return(my_mat)
}
end

* Mortality probabilities (used to calculate age of death)
insheet using "`mort'", comma clear
ren health_state state
save "`tmp_mort'", replace

* Initial health state distribution
insheet using "`population_age50'", comma clear
save "`tmp_population_age50'", replace

***
* Loop over gamma and bequest/non-bequest specifications
* Robustness_q specification: set quality of life equal to 1, and set r=0.03
***
foreach gamma in 0.8 1.25 1.5 {
		
	foreach scen in "base" "bequest" "robustness_q" "robustness_wealth" {
		
		* Note: bequest uses the wealth calibration from the non-bequest model
		if "`scen'"=="base" {
			local beq ""
			local script_analysis "model-baseline/analysis.R"
			
			local qual  "$Longevity/processed/baseline_cohort_quality.csv"
			local rates "$Longevity/processed/returns_oopmd_income.csv"
		}
		else if "`scen'"=="bequest" {
		    if "`gamma'"!="1.25" continue
			
			local beq "$Longevity/processed/baseline_cohort_bequest.csv"
			local script_analysis "model-bequests/analysis_bequests.R"
			
			local qual  "$Longevity/processed/baseline_cohort_quality.csv"
			local rates "$Longevity/processed/returns_oopmd_income.csv"
			
			* analysis_bequests.R has one additional input parameter: `w_0_state1'. It is used to calculate an example path for a figure. (This parameter is ignored by analysis.R)
			local wealth_state1 "$Longevity/results/intermediate/base_`gamma'/w_0_state1.csv"
			insheet using "`wealth_state1'", clear
			local w_0_state1 = x
		}
		else if "`scen'"=="robustness_q" {
			if "`gamma'"!="1.25" continue
			
			local beq ""
			local script_analysis "model-baseline/analysis.R"
			
			local qual  "$Longevity/processed/baseline_cohort_quality_constant.csv"
			local rates "$Longevity/processed/returns_oopmd_income.csv"
		}
		else if "`scen'"=="robustness_wealth" {
			if "`gamma'"!="1.25" continue
			
			local beq ""
			local script_analysis "model-baseline/analysis.R"
			
			local qual  "$Longevity/processed/baseline_cohort_quality.csv"
			local rates "$Longevity/processed/returns_baseline.csv"				
		}		
		
		local FEM_output "$Longevity/results/intermediate/`scen'_`gamma'"
		cap mkdir "`FEM_output'"
		
		* Calculate initial wealth based on a target VSL (varies by gamma)
		rscript using "$Longevity/scripts/programs/model-baseline/wealth_calibration_allstates.R", args("`target_vsl'" "$Longevity" "`tmp'" "`mort'" "`qual'" "`trans'" "`rates'" "`population_age50'" "`income_age50'" "`gamma'")

		* Ensure a minimum of 1 person per health state
		insheet using "`tmp'", comma clear
		ren v1 health_state
		ren wealth_solution wealth
		merge 1:1 health_state using "`tmp_population_age50'", assert(match) nogenerate
		gen nsims = round(`num_sims'*pct/100)
		replace nsims = 1 if nsims==0
		outsheet using "`FEM_output'/wealth_nsims.csv", comma replace
		egen total_nsims = sum(nsims)
		local total_nsims = total_nsims
			
		* Estimate stochastic life-cycle model
		rscript using "$Longevity/scripts/programs/`script_analysis'", args("`FEM_output'/wealth_nsims.csv" "$Longevity" "`FEM_output'" "`mort'" "`qual'" "`trans'" "`rates'" "`rates_alt'" "`beq'" "`gamma'" "`w_0_state1'")

		***
		* Process health shock results
		***
		insheet using "`FEM_output'/c_vsl_w_health_shockbase.csv", comma clear
		ren v1 age
		ren v2 c_oopmd
		ren v3 VSL_oopmd
		ren v4 w_oopmd
		cap ren vslpathsick_cf1 VSL_cf1_oopmd
		cap ren vslpathsick_cf2 VSL_cf2_oopmd
		replace age = age + 49
		save "`FEM_output'/c_vsl_w_health_shock_processed.dta", replace
	
		***
		* Process VSI results
		***
		insheet using "`FEM_output'/sims_vsi_age70.csv", comma clear
		ren v1 state

		reshape long v, i(state) j(sim)
		replace sim = sim-1
		order sim state
		sort sim state
		ren v vsi
		gen age=70
		save "`FEM_output'/sims_vsi_age70_processed.dta", replace
				
		***
		* Process/reshape Monte Carlo simulation results
		***
		foreach f in VSL path wealth {
			
			insheet using "`FEM_output'/sims_`f'_allstates.csv", comma clear
			ren v1 age
			replace age = age + 49
			rename v* `f'*
			
			d, short
			assert r(k)==`total_nsims'+1
			compress
			
			mata: output = reshape()

			drop _all
			getmata (sim age `f') = output
			
			summ sim
			assert r(max) == `total_nsims'
			save "`tmp_`f''", replace
		}

		use "`tmp_VSL'", clear
		merge 1:1 age sim using "`tmp_path'", assert(match) nogenerate
		merge 1:1 age sim using "`tmp_wealth'", assert(match) nogenerate

		sort sim age
		ren path state

		* Identify death ages by assigning deaths in proportion to FEM mortality probabilities
		set seed 11
		merge m:1 age state using "`tmp_mort'", nogenerate assert(match using) keep(match)
		gen died = rbinomial(1,pdied)
		replace died = 1 if abs(pdied-1)<0.000001
		assert !mi(died)

		bysort sim (age): gen died_sum = sum(died)
		by sim age: gen alive = died_sum==0

		keep if alive==1
		keep if age<=80

		keep sim age VSL state wealth
		compress
		save "`FEM_output'/simulations_processed_allstates.dta", replace

		* Limit to health state 1
		gen tmp = inrange(state,1,1) & age==50
		bysort sim: egen tokeep = max(tmp)
		keep if tokeep==1
		drop tmp tokeep
		save "`FEM_output'/simulations_processed.dta", replace
	}
}

***
* For baseline case, calculate counterfactual VSL in the event that a state transition had not occurred
***
local gamma 1.25

local mort  "$Longevity/processed/baseline_cohort_mortality.csv"
local qual  "$Longevity/processed/baseline_cohort_quality.csv"
local trans "$Longevity/processed/baseline_cohort_transitions.csv"
local rates "$Longevity/processed/returns_oopmd_income.csv"

local FEM_output_baseline "$Longevity/results/intermediate/base_1.25"
local sims_inputfile "`FEM_output_baseline'/simulations_processed.csv"
tempfile sims_outputfile
			
use "`FEM_output_baseline'/simulations_processed.dta", clear
sort sim age
by sim: gen state_prev = state[_n-1] if _n>1
by sim: replace state_prev = state if _n==1
outsheet using "`FEM_output_baseline'/simulations_processed.csv", comma replace

rscript using "$Longevity/scripts/programs/model-baseline/analysis_vsl_cf.R", args("$Longevity" "`mort'" "`qual'" "`trans'" "`rates'" "`sims_inputfile'" "`sims_outputfile'" "`gamma'")	

insheet using "`sims_outputfile'", clear
assert abs(vsl_prev - vsl)<1 if age==50
drop v1
save "`FEM_output_baseline'/simulations_processed_cf.dta", replace

** EOF
