************
* SCRIPT: 3_make_tables_figures.do
* PURPOSE: output the tables and figures used in the manuscript
************

* Preamble (unnecessary when executing run.do)
run "$Longevity/scripts/programs/_config.do"
clear


************
* Code begins
************

tempfile t vsl_70
local FEM_data "$Longevity/data/FEM/no_inflation_or_mort_decline"
local FEM_input  "$Longevity/processed"
local FEM_output "$Longevity/results/intermediate/base_1.25"

local texsave_settings "replace autonumber nofix"

*******
* Calibration overview table
*******

***
* Initial wealth
***
local run_no = 0
foreach gamma in 0.8 1.25 1.5 {	
	foreach scen in "base" "bequest" "robustness_q" "robustness_wealth" {
		
		cap insheet using "$Longevity/results/intermediate/`scen'_`gamma'/wealth_nsims.csv", clear
		if _rc continue
		gen gamma = "`gamma'"
		gen scen = "`scen'"
		
		if `run_no'>0 append using "`t'"
		save "`t'", replace
		local run_no=1
	}
}

use "`t'", clear

* Baseline
summ wealth if gamma=="1.25" & scen=="base" [aw=pct]
local w0_mean : di %9.0fc round(r(mean),10000)
local w0_sd : di %7.0fc round(r(sd),10000)

* Alternatives
drop if gamma=="1.25" & scen=="base"

local mean_min = .
local mean_max = 0
local sd_min = .
local sd_max = 0
foreach gamma in 0.8 1.25 1.5 {	
	foreach scen in "base" "bequest" "robustness_q" "robustness_wealth" {
		
		cap summ wealth if gamma=="`gamma'" & scen=="`scen'" [aw=pct]
		if r(mean)==. continue
		
		if r(mean)<`mean_min' local mean_min = r(mean)
		if r(mean)>`mean_max' local mean_max = r(mean)
		
		if r(sd)<`sd_min' local sd_min = r(sd)
		if r(sd)>`sd_max' local sd_max = r(sd)
		
	}
}

local w0_mean_min : di %9.0fc round(`mean_min',10000)
local w0_mean_max : di %9.0fc round(`mean_max',10000)
local w0_sd_min : di %7.0fc round(`sd_min',10000)
local w0_sd_max : di %7.0fc round(`sd_max',10000)


***
* interest rate, quality of life, and mortality
***

* Calculate weights = proportion of people in each age X state
use "$Longevity/results/intermediate/base_1.25/simulations_processed.dta", clear
gen count = 1
collapse (sum) count, by(age state) fast
egen total = sum(count)
gen weight = count/total
ren state health_state
keep age health_state weight
tempfile weights
save "`weights'", replace

* States that are never realized receive weight of 0
insheet using "$Longevity/processed/baseline_cohort_transitions.csv", clear
reshape long phealth, i(age health_state) j(to_state)
ren phealth tprob
merge m:1 age health_state using "`weights'", assert(master match) nogenerate
replace weight = 0 if mi(weight)
tempfile transition_probs
save "`transition_probs'", replace

insheet using "$Longevity/processed/returns_oopmd_income.csv", clear
reshape long rhealth, i(age health_state) j(to_state)
merge 1:1 age health_state to_state using "`transition_probs'", assert(match) nogenerate
gen finalwt = weight*tprob
egen tmp2 = sum(finalwt)
assert abs(tmp2-1)<0.00001
drop tmp2

summ rhealth [aw=finalwt]
local rhealth_mean : di %5.4fc r(mean)
local rhealth_sd : di %5.4fc r(sd)

summ tprob [aw=finalwt]
local tprob_mean : di %5.4fc r(mean)
local tprob_sd : di %5.4fc r(sd)

summ tprob if to_state==20 [aw=weight]
local mort_mean : di %5.4fc r(mean)
local mort_sd : di %5.4fc r(sd)

insheet using "$Longevity/processed/baseline_cohort_quality.csv", clear
merge 1:1 age health_state using "`weights'", assert(master match) nogenerate
replace weight = 0 if mi(weight)

summ quality [aw=weight]
local q_mean : di %5.4fc r(mean)
local q_sd : di %5.4fc r(sd)


drop _all
set obs 19
local i = 1
gen parameter = "\(\sigma\)" in `i'
gen description = "Elasticity of intertemporal substitution" in `i'
local ++i

replace parameter = "\underline{c}" in `i'
replace description = "Minimum viable consumption level" in `i'
local ++i

replace parameter = "\(b(t)\)" in `i'
replace description = "Bequest motive" in `i'
local ++i

replace parameter = "\(\rho\)" in `i'
replace description = "Rate of time preference" in `i'
local ++i

replace parameter = "\(r(t,Y_t,Y_{t+1})\)" in `i'
replace description = "Age- and state-dependent interest rate" in `i'
replace parameter = "\ \ \ \ Mean" in `=`i'+1'
replace parameter = "\ \ \ \ Std.\ dev." in `=`i'+2'
local i = `i'+3

replace parameter = "\(q_{Y_t}(t)\)" in `i'
replace description = "Age- and state-dependent quality of life" in `i'
replace parameter = "\ \ \ \ Mean" in `=`i'+1'
replace parameter = "\ \ \ \ Std.\ dev." in `=`i'+2'
local i = `i'+3

replace parameter = "\(p_{Y_t,Y_{t+1}}(t)\)" in `i'
replace description = "Age- and state-dependent transition probability" in `i'
replace parameter = "\ \ \ \ Mean" in `=`i'+1'
replace parameter = "\ \ \ \ Std.\ dev." in `=`i'+2'
local i = `i'+3

replace parameter = "\(\bar{d}_{Y_t}(t)\)" in `i'
replace description = "Age- and state-dependent mortality probability" in `i'
replace parameter = "\ \ \ \ Mean" in `=`i'+1'
replace parameter = "\ \ \ \ Std.\ dev." in `=`i'+2'
local i = `i'+3



replace parameter = "\(W_0(Y_t)\)" in `i'
replace description = "State-dependent initial wealth at age 50" in `i'
replace parameter = "\ \ \ \ Mean" in `=`i'+1'
replace parameter = "\ \ \ \ Std.\ dev." in `=`i'+2'
local i = `i'+3

gen baseline = "0.8" if strpos(parameter,"sigma")
gen alt = "2/3--1.25" if strpos(parameter,"sigma")

replace baseline = "`=char(92)'`=char(36)'5,000" if strpos(parameter,"underline{c}")
replace alt      = "`=char(92)'`=char(36)'5,000" if strpos(parameter,"underline{c}")

replace baseline = "0.03" if strpos(parameter,"rho")
replace alt      = "0.03" if strpos(parameter,"rho")

replace baseline = "0" if strpos(parameter,"b(t)")
replace alt      = "1.2" if strpos(parameter,"b(t)")

replace baseline = "`q_mean'" if strpos(parameter[_n-1],"q_{Y_t}(t)")
replace baseline = "`q_sd'"   if strpos(parameter[_n-2],"q_{Y_t}(t)")
replace alt = "1"   if strpos(parameter[_n-1],"q_{Y_t}(t)")
replace alt = "0"   if strpos(parameter[_n-2],"q_{Y_t}(t)")

replace baseline = "`tprob_mean'" if strpos(parameter[_n-1],"p_{Y_t,")
replace baseline = "`tprob_sd'"   if strpos(parameter[_n-2],"p_{Y_t,")
replace alt      = "`tprob_mean'" if strpos(parameter[_n-1],"p_{Y_t,")
replace alt      = "`tprob_sd'"   if strpos(parameter[_n-2],"p_{Y_t,")

replace baseline = "`mort_mean'" if strpos(parameter[_n-1],"\bar{d}_{Y_t}")
replace baseline = "`mort_sd'"   if strpos(parameter[_n-2],"\bar{d}_{Y_t}")
replace alt      = "`mort_mean'" if strpos(parameter[_n-1],"\bar{d}_{Y_t}")
replace alt      = "`mort_sd'"   if strpos(parameter[_n-2],"\bar{d}_{Y_t}")

replace baseline = "`rhealth_mean'" if strpos(parameter[_n-1],"r(t,")
replace baseline = "`rhealth_sd'"   if strpos(parameter[_n-2],"r(t,")
replace alt = "0.03"  if strpos(parameter[_n-1],"r(t,")
replace alt = "0"     if strpos(parameter[_n-2],"r(t,")

replace baseline = "`=char(92)'`=char(36)'`w0_mean'" if strpos(parameter[_n-1],"W_0(Y_t)")
replace baseline = "`=char(92)'`=char(36)'`w0_sd'"   if strpos(parameter[_n-2],"W_0(Y_t)")
replace alt = "`=char(92)'`=char(36)'`w0_mean_min'--`=char(92)'`=char(36)'`w0_mean_max'" if strpos(parameter[_n-1],"W_0(Y_t)")
replace alt = "`=char(92)'`=char(36)'`w0_sd_min'--`=char(92)'`=char(36)'`w0_sd_max'"   if strpos(parameter[_n-2],"W_0(Y_t)")

gen lit = "Estimates from prior studies range from 0.5--1.5 \citep{Hall1988, Attanasio2010, Attanasio1993, Bansal2004, Murphy2006}."  if strpos(parameter,"sigma")
replace lit = "\citet{Murphy2006} consider minimum viable consumption ranges of 5--20 percent of full income." if strpos(parameter,"underline{c}")
replace lit = "See \citet{Siegel1992} and \citet{Moore1990}." if strpos(parameter,"rho")
replace lit = "\citet{Fischer1973} considers values ranging from 0.42 to 1.20." if strpos(parameter,"b(t)")
replace lit = "\multirow[t]{3}{=}{Based on a baseline interest rate of \(r=0.03\) \citep{Siegel1992,Moore1990}; FEM medical spending and earnings data; and average Social Security benefits.}" if strpos(parameter,"r(t,")
replace lit = "Future Elderly Model" if strpos(parameter,"q_{Y_t}(t)")
replace lit = "Future Elderly Model" if strpos(parameter,"p_{Y_t,")
replace lit = "Future Elderly Model" if strpos(parameter,"\bar{d}_{Y_t}")
replace lit = "\multirow[t]{3}{=}{Calibrated to yield an average VSL of `=char(92)'`=char(36)'6 million \citep{Murphy2006,OBrien2018}.}" if strpos(parameter,"W_0(Y_t)")

label var parameter "Parameter"
label var description "Description"
label var baseline "Baseline"
label var alt "Alternatives"
label var lit "Literature/data sources"

ingap 2 3 4 5 8 8 11 14 17

local title "Parameter values and sources for the numerical model calibration"
local fn "Notes: This table displays the parameter values used in the numerical model described in Section \ref{S - Empirics}. Column (3) lists the parameter values for the baseline specification, while Column (4) provides the values for the alternative specifications shown in Figures \ref{F - Robustness} and \ref{F - Robustness2}. Means and standard deviations are weighted by the prevalence of different age and state realizations over the life cycle."
local tablelines `"tablelines("\newcolumntype{W}[1]{>{\raggedright\arraybackslash}p{#1}}" "\newcolumntype{T}[1]{>{\centering\arraybackslash}p{#1}}")"'
local headerlines `"headerlines2("{(1)}&{(2)}&{(3)}&{(4)}&{(5)} \tabularnewline \midrule && \multicolumn{2}{c}{Parameter values}& \tabularnewline \cmidrule(r){3-4}")"'
texsave using "$Longevity/results/tables/calibration.tex", varlabels title("`title'") footnote("`fn'", size(3)) label(T - calibration) size(3) `tablelines'  `headerlines'  align(llT{2cm}CW{7cm}) landscape replace nofix

*******
* Heterogeneity in VSL 
*******

***
* Histogram of VSL at age 70
***
use "`FEM_output'/simulations_processed.dta", clear

* 22,214 healthy adults (state 1) at age 50
count if age==50
assert r(N)==22214

replace VSL = VSL/1000

summ VSL if age==70
local vsl_mean_age70 = trim("`: di %4.0fc r(mean)'")

graph twoway histogram VSL if age==70, xlabel(, nogrid) xtitle("VSL (thousands of dollars)", size(medium)) ytitle("Frequency", size(medlarge)) freq ylab(,format(%12.0fc) angle(horizontal) gstyle(default)) || function y=`vsl_mean_age70', horizontal range(0 3000) lwidth(medthick) legend(off) text(3100 2330 "Mean = `vsl_mean_age70'", place(e))
graph export "$Longevity/results/figures/mc_vsl_age70.pdf", replace as(pdf)

***
* Spaghetti plot of VSL, by age
***
local pct_stats
local graph_nms
local lwidth
local lcolor
local cmd 
*foreach x of numlist 1 2 3 4 5(5)95 96 97 98 99 {
foreach x of numlist 1 2 3 4 10(5)90 96 97 98 99 5 95{	
	local pct_stats "`pct_stats' (p`x') p`x'_VSL=VSL"
	
	local graph_nms "`graph_nms' p`x'_VSL"
	local lwidth "`lwidth' medium"
	local lcolor "`lcolor' blue*0.2"	
	*local cmd "`cmd' || line p`x'_VSL age, lwidth(medium) lcolor(blue*0.2)"
	
	if inlist(`x',5,95) local cmd "`cmd' || line p`x'_VSL age, lwidth(medthick) lcolor(blue) lpattern(dash)"
	else local cmd "`cmd' || line p`x'_VSL age, lwidth(medium) lcolor(blue*0.2)"
}

collapse (mean) mean_VSL=VSL `pct_stats', by(age) fast

* "By age 70, the VSL inter-vigintile range spans \$1.7 to \$2.9 million."
assert abs(p5_VSL - 1732)<1 if age==70
assert abs(p95_VSL - 2849)<1 if age==70

format mean_VSL %12.0fc
label var mean_VSL "Mean"
label var age "Age"
graph twoway `cmd' || line mean_VSL age, lwidth(thick) lcolor(blue) ytitle("VSL (thousands of dollars)", size(medlarge)) xlabel(,nogrid) ylabel(0(1000)7000, angle(horizontal) gstyle(default) format(%5.0fc)) xtitle("Age", size(medlarge)) legend(off)
graph export "$Longevity/results/figures/mc_vsl_variance.pdf", replace as(pdf)


*******
* Shocks
*******

* LE and QALY by age/state (descriptive stats)
insheet using "`FEM_output'/age_state_le_qaly.csv", comma clear
drop v1
replace v2 = v2+49
ren v2 age
ren v3 state
ren v4 LE
ren v5 QALE

assert QALE<LE
tempfile le_qaly
save "`le_qaly'", replace

* "a modest health shock at age 60 that reduces her life expectancy by 3.0 years, suffers a severe health shock at age 70 that reduces life expectancy by 6.8 years, and then dies at age 75"
summ LE if age==60 & state==1
local LE1 = r(mean)
summ LE if age==60 & state==6
local LE2 = r(mean)
assert abs(`LE1' - `LE2' - 3.0) < 0.05

summ LE if age==70 & state==6
local LE3 = r(mean)
summ LE if age==70 & state==14
local LE4 = r(mean)
assert abs(`LE3' - `LE4' - 6.8) < 0.05

* "Life expectancy for a 70-year-old in health state 1 is equal to 11.0 QALYs"
keep if age==70 & state==1
assert abs(QALE-10.95534)<0.001


***
* VSL shocks -- use counterfactual values
***

use "`FEM_output'/simulations_processed_cf.dta", clear

merge m:1 age state using "`le_qaly'", assert(match using) keep(match) nogenerate keepusing(QALE LE)
ren vsl VSL
replace VSL = VSL/1000
replace vsl_prev = vsl_prev/1000
gen VSLY = VSL/QALE
label var VSLY "VSL per QALY (thousands of dollars)"
ren QALE QALE_current

ren state state_current
ren state_prev state
merge m:1 age state using "`le_qaly'", assert(match using) keep(match) nogenerate keepusing(QALE)
gen vsly_prev = vsl_prev/QALE
ren state state_prev
ren QALE QALE_prev
ren state_current state
ren QALE_current QALE

bysort sim (age): gen shock = state!=state[_n-1] & _n!=1
gen vsl_diff  = VSL  - vsl_prev if shock==1
gen vsly_diff = VSLY - vsly_prev if shock==1

count if shock==1
local num_shocks = trim("`: di %11.0gc r(N)'")
assert "`num_shocks'"=="58,088"

* On average, a health shock increases VSL by \$16,000 (<1%)
format vsl_diff %12.0fc
summ vsl_diff, detail
assert abs(16.2 - r(mean))<1
local vsl_diff_mean = trim("`: di %4.1fc r(mean)'")

summ VSL if shock[_n+1]==1
assert abs(16.2/r(mean))<.005
local mean_prior_yr = trim("`: di %5.0fc r(mean)'")

graph twoway histogram vsl_diff if shock==1, xlabel(,nogrid) xtitle("Change in VSL (thousands of dollars)", size(medium)) ytitle("Frequency", size(medlarge)) freq ylabel(,format(%12.0fc) angle(horizontal) gstyle(default)) || function y=`vsl_diff_mean', horizontal range(0 20000) lwidth(medthick) legend(off) note("Mean VSL in year prior to shock = `mean_prior_yr' (thousands of dollars)") text(20815.74178872469 -6 "Mean = `vsl_diff_mean'", place(e))
graph export "$Longevity/results/figures/mc_vsl_change.pdf", replace as(pdf)

* "This second plot shows that health shocks increase VSL per QALY by \$70,000 (21\%), on average"
summ vsly_diff, detail
assert abs(70 - r(mean))<.5
local vsly_diff_mean = trim("`: di %4.1fc r(mean)'")

* "The distribution is skewed to the right, with the value of a QALY rising by over \$150,000 (45\%) in 5 percent of cases."
assert abs(r(p95) -  158.7)<1

summ VSLY if shock[_n+1]==1
local mean_prior_yr = trim("`: di %5.0fc r(mean)'")

graph twoway histogram vsly_diff if shock==1, xlabel(,nogrid) xtitle("Change in VSL/QALY (thousands of dollars)", size(medium)) ytitle("Frequency", size(medlarge)) freq ylabel(,format(%12.0fc) angle(horizontal) gstyle(default)) || function y=`vsly_diff_mean', horizontal range(0 25000) lwidth(medthick) legend(off) note("Mean VSL/QALY in year prior to shock = `mean_prior_yr' (thousands of dollars)") text(25800 25 "Mean = `vsly_diff_mean'", place(e))
graph export "$Longevity/results/figures/mc_vsly_change.pdf", replace as(pdf)

* 3\% of shocks increase VSL by over \$50,000, while 5\% cause VSL to fall
count if shock==1
local n = r(N)

count if vsl_diff>50 & shock==1
assert abs(r(N)/`n'-.03)<.005
count if vsl_diff<0 & shock==1
assert abs(r(N)/`n'-.05)<.005


***
* VSL and VSL per QALY at age 70
***
keep if age==70

collapse (mean) VSL VSLY, by(state LE QALE) fast
preserve
	keep if state==1
	gen state_sick = 21
	gen QALE_sick = 0
	ren VSL vsi
	gen VSIY = vsi/QALE
	keep state_sick QALE_sick vsi VSIY
	save "`vsl_70'", replace
restore

format VSL %12.0fc
label var LE "Life expectancy"
label var VSL "VSL (thousands of dollars)"
sort QALE
label var VSLY "VSL per QALY (thousands of dollars)"
label var VSL "VSL"
label var VSLY "VSL per QALY"
local yaxis1_options `"yscale(range(0 500) axis(1)) ylabel(0(500)3000, axis(1) angle(horizontal) gstyle(default)) ytitle("VSL (thousands of dollars)", size(medlarge)) legend(position(6) cols(2) region(lstyle(solid)))"'
local yaxis2_options `"yscale(range(0 500) axis(2)) ylabel(0(100)500, axis(2) angle(horizontal) gstyle(default)) ytitle("VSL per QALY (thousands of dollars)", size(medlarge) axis(2))"'
graph twoway connected VSL QALE, yaxis(1) `yaxis1_options' lcolor(blue) lwidth(medthick) mcolor(blue) msymbol(square) lpattern(shortdash) || connected VSLY QALE, yaxis(2) `yaxis2_options' lpattern(solid) lwidth(medthick) lcolor(red) mcolor(red) xlabel(,nogrid) xtitle("Life expectancy at age 70 (QALYs)", size(medlarge))
graph export "$Longevity/results/figures/mc_vsl_vsly_age70.pdf", replace as(pdf)

* Individuals in the worst health state have an average VSL per QALY of \$630,000, over 2.4 times higher than individuals in the healthiest state, where VSL per QALY is \$260,000
assert abs(VSLY-260)<0.1 if state==1
assert abs(VSLY-500)<5 if state==20
assert abs(500/260 - 1.9)<.05

* Life expectancy in worst health state: 2.6 QALYs
* Life expectancy in best health state: 11 QALYs
assert abs(QALE-2.556804)<0.01 if state==20
assert abs(QALE-10.95534)<0.01 if state==1



***
* VSI at age 70 and state 1
***
use "`FEM_output'/sims_vsi_age70_processed.dta", clear
merge m:1 age state using "`le_qaly'", assert(match using) keep(match) keepusing(QALE) nogenerate
ren QALE QALE_sick

ren state state_sick
gen state = 1
merge m:1 age state using "`le_qaly'", assert(match using) keep(match) keepusing(QALE) nogenerate
ren QALE QALE_healthy

gen diff = QALE_healthy - QALE_sick

assert diff<0.001 if state_sick==1
drop if state_sick==1

assert diff>0
assert diff<QALE_healthy
gen VSIY = vsi/diff

collapse (mean) VSIY vsi, by(state_sick QALE_sick) fast
replace VSIY = VSIY/1000
replace vsi = vsi/1000

append using "`vsl_70'"

sort QALE_sick

* "Reducing the risk of death (\$260,000 per QALY) is worth 10\% more per QALY than reducing the risk of transitioning to health state 2 (\$237,000 per QALY), the mildest possible illness in our model (life expectancy of 9.7 QALYs)."
assert abs(VSIY-260)<.5 if state_sick==21
assert abs(VSIY-237)<.5 if state_sick==2
assert abs(260/237 - 1.10)<0.005
assert abs(QALE_sick-9.737671)<0.001 if state_sick==2

* A marginal reduction in the probability of transitioning to the worst health state (2.6 QALYs) is worth about \$2.1 million
assert abs(QALE_sick - 2.556804)<0.01 if state_sick==20
assert abs(vsi - 2088)<1 if state_sick==20

* VSL, which is a special case of VSI where life expectancy is 0 years in the sick state, is \$2.8 million. 
assert abs(vsi - 2849)<1 if state_sick==21


format VSIY %12.0fc
label var VSIY "VSI per QALY (thousands of dollars)"

format vsi %12.0fc
label var vsi "VSI"
local yaxis1_options `"yscale(range(0 500) axis(1)) ylabel(0(500)3000, axis(1) angle(horizontal) gstyle(default)) ytitle("VSI (thousands of dollars)", size(medlarge)) legend(position(6) cols(2) region(lstyle(solid)))"'
local yaxis2_options `"yscale(range(0 250) axis(2)) ylabel(0(50)250, axis(2) angle(horizontal) gstyle(default)) ytitle("VSI per QALY (thousands of dollars)", size(medlarge) axis(2))"'
graph twoway connected vsi QALE_sick, yaxis(1) `yaxis1_options' lcolor(blue) lwidth(medthick) mcolor(blue) msymbol(square) lpattern(shortdash) || connected VSIY QALE_sick, yaxis(2) `yaxis2_options' lpattern(solid) lwidth(medthick) lcolor(red) mcolor(red) xlabel(,nogrid) text(-265 0.1 "(death)", place(e)) xtitle("Life expectancy when ill (QALYs)", size(medlarge))
graph export "$Longevity/results/figures/mc_vsi_vsiy_age70.pdf", replace as(pdf)


*******
* Spending shocks
*******

use "`FEM_output'/`scen'/c_vsl_w_health_shock_processed.dta", clear
keep  age c_oopmd VSL_oopmd VSL_cf1_oopmd  VSL_cf2_oopmd
order age c_oopmd VSL_oopmd

foreach v in c_oopmd VSL_oopmd VSL_cf1_oopmd VSL_cf2_oopmd {
	replace `v' = `v'/1000
}
summ VSL_cf1_oopmd if age==60
local cf1 = r(mean)

summ VSL_cf2_oopmd if age==70
local cf2 = r(mean)

label var c_oopmd "Consumption"
label var VSL_oopmd "VSL"
label var age "Age"

format c_oopmd %12.0fc
format VSL_oopmd %12.0fc

keep if age<=75
local graph_options `"xlabel(,nogrid) legend(label(3 "Counterfactual VSL") position(6) cols(2) region(lstyle(solid))) legend(position(6) region(lstyle(solid)))"'
graph twoway line c_oopmd age, lpattern(shortdash) lwidth(thick) lcolor(blue) || line VSL_oopmd age, yaxis(2) ytitle("Consumption (thousands of dollars)", axis(1) size(medlarge)) ytitle("VSL (thousands of dollars)", axis(2) size(medlarge)) lwidth(thick thick) lpattern(solid dot) lcolor(red black) `graph_options' yscale(range(0) axis(1)) yscale(range(0) axis(2)) ylabel(0(10)100, axis(1) angle(horizontal) gstyle(default))  ylabel(0(1000)7000, axis(2) angle(horizontal) gstyle(default)) || scatteri `cf1' 60 `cf2' 70, yaxis(2) msymbol(X) msize(medlarge) mcolor(black) xtitle("Age", size(medlarge))
graph export "$Longevity/results/figures/c_vsl_shock.pdf", replace as(pdf)

* "VSL is unaffected by the shock at age 60, but rises by 5 percent age age 70."
assert abs(VSL_cf2_oopmd-2566)<1 if age==70
assert abs(VSL_oopmd-2686)<1 if age==70
assert abs(2686/2566 - 1.05)<.005

***********************************
* Descriptive stats table: transition probs, quality of life, spending, and life expectancy
***********************************
insheet using "`FEM_input'/baseline_cohort_transitions.csv", comma clear
keep if inlist(age,50,70)
gen exit_prob = .
forval x = 1/20 {
	replace exit_prob = 1-phealth`x' if health_state==`x'
}
keep age health_state exit_prob
reshape wide exit_prob, i(health_state) j(age)
save "`t'", replace

use "`FEM_data'/baseline_cohort_oopmd_1yr.dta", clear
keep if inlist(age,50,70)
ren l2health health_state
reshape wide oopmd, i(health_state) j(age)
merge 1:1 health_state using "`t'", assert(match) nogenerate
save "`t'", replace

insheet using "`FEM_input'/baseline_cohort_quality.csv", comma clear
keep if inlist(age,50,70)
reshape wide quality, i(health_state) j(age)
merge 1:1 health_state using "`t'", assert(match) nogenerate
save "`t'", replace

use "$Longevity/data/fem/baseline_cohort_iearnx_1yr.dta", clear
keep if inlist(age,50,70)
ren l2health health_state
ren iearnx earnings
replace earnings = earnings*1000
reshape wide earnings, i(health_state) j(age)
merge 1:1 health_state using "`t'", assert(match) nogenerate
save "`t'", replace

use "`le_qaly'", clear
keep if inlist(age,50,70)
reshape wide LE QALE, i(state) j(age)
ren state health_state
merge 1:1 health_state using "`t'", assert(match) nogenerate

* Format and output table
foreach v of varlist exit* {
	replace `v' = `v'*100
}

save "$Longevity/results/intermediate/summary_stats.dta", replace


* Summary statistics, by health state
use "$Longevity/results/intermediate/summary_stats.dta", clear

*gen index = QALE70

tostring LE*, replace format(%12.1fc) force
tostring QALE*, replace format(%12.1fc) force
tostring qual*, replace format(%5.2fc) force
tostring oop*, replace format(%6.0fc) force
tostring earnings*, replace format(%6.0fc) force
tostring exit*, replace format(%5.1fc) force

tostring health_state, replace
*replace health_state = "1 (healthy)" if health_state=="1"

gen adls = floor((_n-1)/5)
gen cc = mod(_n-1,5)
tostring adls cc, replace
replace adls = "3+" if adls=="3"
replace cc = "4+" if cc == "4"

gen adls_cc = adls + " / " + cc
*replace adls_cc = subinstr(adls_cc," / ", "\hphantom{+} / ", 1) if substr(adls_cc,2,1)!="+"
drop adls cc
order health_state adls_cc

label var health_state "Health state"
label var adls_cc "ADLs / CCs"
foreach v of varlist *50 {
	label var `v' "Age 50"
}
foreach v of varlist *70 {
	label var `v' "Age 70"
}
order health_state adls_cc LE50 LE70 QALE50 QALE70 quality50 quality70 oopmd50 oopmd70 earnings50 earnings70


*gsort -index
*drop index

local title "Summary means for the Future Elderly Model data, by health state"
local headerlines "& & \multicolumn{2}{c}{Life expectancy (years)}  & \multicolumn{2}{c}{Life expectancy (QALYs)} & \multicolumn{2}{c}{Quality of life (EQ-5D)} & \multicolumn{2}{c}{Medical spending (2010 \\\\\\\\$)} & \multicolumn{2}{c}{Labor earnings (2010 \\\\\\\\$)} & \multicolumn{2}{c}{Exit probability (\%)}" "\cmidrule(lr){3-4} \cmidrule(lr){5-6} \cmidrule(lr){7-8} \cmidrule(lr){9-10} \cmidrule(lr){11-12} \cmidrule(lr){13-14}"
local fn "Notes: This table reports selected means for the health data obtained from the Future Elderly Model (FEM). Column (1) reports the number of impaired activities of daily living (ADLs) and the number of chronic conditions (CCs), which together define a health state. Columns (2)--(3) report life expectancy in years. Columns (4)--(5) report life expectancy in QALYs, which is calculated using Equation \eqref{E - QALE} with a 3\% discount rate. Columns (6)--(7) report average quality of life as measured by the EQ-5D, where 1 indexes perfect health. Columns (8)--(9) report average annual out-of-pocket medical spending, which includes all inpatient, outpatient, prescription, and long-term care spending not covered by insurance. Columns (10)--(11) report average labor earnings. Columns (12)--(13) report the percentage probability that an individual transitions to a different health state in the following year (excluding death). All impaired ADLs and chronic conditions are permanent, i.e., individuals can transition only to higher-numbered health states. Additional details about the FEM are available in Appendix \ref{S - Appendix - Data}."

texsave using "$Longevity/results/tables/summary_stats.tex", label(T - summary_stats) size(scriptsize) landscape align(llCCCCCCCCCCCC) footnote("`fn'", size(scriptsize)) title("`title'") headerlines("`headerlines'") varlabels `texsave_settings'


***********************************
* Life expectancy table
***********************************
use "$Longevity/results/intermediate/summary_stats.dta", clear
gen adls = floor((_n-1)/5)
gen cc = mod(_n-1,5)
keep adls cc QALE70 LE70 health_state

reshape wide QALE70 LE70 health_state, i(adls) j(cc)
tostring QALE* LE*, replace format(%12.1fc) force
tostring health*, replace
tostring adls, replace
replace adls = "3+" if adls=="3"

label var adls "Number of ADLs"
*replace LE700 = LE700 + " years" if adls=="0"
*replace QALE700 = QALE700 + " QALYs" if adls=="0"

ingap 2 3 4
set obs 8
forval x = 0/4 {
	label var LE70`x' "`x'"
	replace LE70`x' = LE70`x' + " [" + QALE70`x' + "]" if !mi(LE70`x')
	replace LE70`x' = "(State " + health_state`x'[_n-1] + ")" if mi(LE70`x')
}
label var LE704 "4+"
drop QALE* health*
ingap 3 5 7

local title "Life expectancy (years and QALYs) at age 70, by health status"
local headerlines "& \multicolumn{5}{c}{Number of chronic conditions}" "\cmidrule(r){2-6}"
local fn "Notes: This table reports life expectancy in years at age 70, by number of impaired activities of daily living (ADLs) and chronic conditions. Life expectancy in QALYs, reported in brackets, is calculated using Equation \eqref{E - QALE} with a 3\% discount rate. Data are obtained from the Future Elderly Model (FEM).  Additional details about the FEM are available in Appendix \ref{S - Appendix - Data}."

texsave using "$Longevity/results/tables/summary_stats_qale70.tex", label(T - summary_stats_qale70) footnote("`fn'") title("`title'") headerlines("`headerlines'") varlabels `texsave_settings'

***********************************
* Spending summary statistics figure
***********************************

use "$Longevity/processed/baseline_cohort_oopmd.dta", clear
replace oopmd = oopmd/1000

reshape wide oopmd, i(age) j(health_state)

label var oopmd1 "State 1 (healthy)"
label var oopmd7 "State 7"
label var oopmd20 "State 20"

graph twoway line oopmd1 oopmd7 oopmd20 age, lpattern(solid longdash shortdash) lwidth(thick thick thick) lcolor(red green blue) xtitle("Age", size(medlarge)) xlab(,nogrid) ylab(0(2)12,angle(horizontal) gstyle(default)) legend(position(6) cols(4) region(lstyle(solid)))
graph export "$Longevity/results/figures/medical_spending.pdf", as(pdf) replace

***********************************
* Earnings summary statistics figure
***********************************

use "$Longevity/data/fem/baseline_cohort_iearnx_1yr.dta", clear
drop if age>100
assert inrange(age,50,100)

ren l2health health_state
ren iearnx earnings

reshape wide earnings, i(age) j(health_state)

label var earnings1 "State 1 (healthy)"
label var earnings7 "State 7"
label var earnings20 "State 20"


graph twoway line earnings1 earnings7 earnings20 age, lpattern(solid longdash shortdash) lwidth(thick thick thick) lcolor(red green blue) xtitle("Age", size(medlarge)) xlab(,nogrid) ylab(,angle(horizontal) gstyle(default)) legend(position(6) cols(4) region(lstyle(solid)))
graph export "$Longevity/results/figures/earnings.pdf", as(pdf) replace

***********************************
* Robustness checks
***********************************
local FEM_output "$Longevity/results/intermediate"
tempfile cons_vsl simulations vsiy

local replace
foreach scen in base_0.8 base_1.25 base_1.5 bequest_1.25 robustness_q_1.25 robustness_wealth_1.25 {
	
	***
	* consumption/VSL shock
	***
	use "`FEM_output'/`scen'/c_vsl_w_health_shock_processed.dta", clear	
	gen scen = "`scen'"
	
	keep if age<=75
	replace c_oopmd = c_oopmd/1000
	replace VSL_oopmd = VSL_oopmd/1000
	label var age "Age"

	format c_oopmd %12.0fc
	format VSL_oopmd %12.0fc	
	
	if "`replace'"!="" append using "`cons_vsl'"
	save "`cons_vsl'", `replace'
	
	***
	* Simulations
	***
	use "`FEM_output'/`scen'/simulations_processed.dta", clear
	merge m:1 age state using "`le_qaly'", assert(match using) nogenerate

	replace VSL = VSL/1000
	gen VSLY = VSL/QALE
	label var VSLY "VSL per QALY (thousands of dollars)"
	
	gen VSLY_LE = VSL/LE
	label var VSLY_LE "VSL per LY (thousands of dollars)"

	gen scen = "`scen'"
	
	if "`replace'"!="" append using "`simulations'"
	save "`simulations'", `replace'
	
	***
	* VSIY
	*** 
	use "`FEM_output'/`scen'/sims_vsi_age70_processed.dta", clear
	merge m:1 age state using "`le_qaly'", assert(match using) keep(match) keepusing(QALE LE) nogenerate
	ren QALE QALE_sick
	ren LE LE_sick

	ren state state_sick
	gen state = 1
	merge m:1 age state using "`le_qaly'", assert(match using) keep(match) keepusing(QALE LE) nogenerate
	ren QALE QALE_healthy
	ren LE LE_healthy

	gen diff    = QALE_healthy - QALE_sick
	gen diff_LE = LE_healthy - LE_sick

	assert diff<0.001 if state_sick==1
	assert diff_LE<0.001 if state_sick==1
	drop if state_sick==1

	assert diff   >0
	assert diff_LE>0
	assert diff   <QALE_healthy
	assert diff_LE<LE_healthy

	replace vsi = vsi/1000
	gen VSIY    = vsi/diff
	gen VSIY_LE = vsi/diff_LE
	
	gen scen = "`scen'"
	
	if "`replace'"!="" append using "`vsiy'"
	save "`vsiy'", `replace'	
	
	local replace replace
}

local graph_options `"legend(label(1 "{&gamma}=0.8") label(2 "{&gamma}=1.25 (baseline)") label(3 "{&gamma}=1.5") label(4 "Bequest") position(6) cols(4) region(lstyle(solid))) xlab(,nogrid) ylab(,angle(horizontal) gstyle(default))"'
local common_opts "lwidth(thick) "
local plot1 "lpattern(longdash)     lcolor(green) mcolor(green) msize(large) msymbol(X)           `common_opts'"
local plot2 "lpattern(solid)        lcolor(red)   mcolor(red)   msize(medlarge) msymbol(circle)   `common_opts'"
local plot3 "lpattern(shortdash)    lcolor(blue)  mcolor(blue)  msize(medlarge) msymbol(square)   `common_opts'"
local plot4 "lpattern(longdash_dot) lcolor(black) mcolor(black) msize(medlarge) msymbol(triangle) `common_opts'"

***********************************
* First set of robustness figures: vary gamma and vary bequest motive
***********************************

* cons/vsl
use "`cons_vsl'", clear

graph twoway line c_oopmd age if scen=="base_0.8", `plot1' ytitle("Thousands of dollars", size(medlarge)) || line c_oopmd age if scen=="base_1.25", `plot2' || line c_oopmd age if scen=="base_1.5", `plot3' || line c_oopmd age if scen=="bequest_1.25", `plot4' `graph_options' 
graph export "$Longevity/results/figures/robustness_consumption.pdf", replace as(pdf)

graph twoway line VSL_oopmd age if scen=="base_0.8", `plot1' ytitle("Thousands of dollars", size(medlarge)) || line VSL_oopmd age if scen=="base_1.25", `plot2' || line VSL_oopmd age if scen=="base_1.5", `plot3' || line VSL_oopmd age if scen=="bequest_1.25", `plot4'  ylabel(0(1000)7000, angle(horizontal)) `graph_options'
graph export "$Longevity/results/figures/robustness_vsl.pdf", replace as(pdf)


* VSL per QALY at age 70
use "`simulations'" if age==70, clear
collapse (mean) VSL VSLY VSLY_LE, by(state LE QALE scen) fast

preserve
	keep if state==1
	gen state_sick = 21
	gen QALE_sick = 0
	gen LE_sick = 0
	ren VSL vsi
	gen VSIY = vsi/QALE
	gen VSIY_LE = vsi/LE
	keep *_sick vsi VSIY VSIY_LE scen
	save "`vsl_70'", replace
restore

sort scen QALE
label var QALE "Life expectancy at age 70 (QALYs)"
graph twoway connected VSLY QALE if scen=="base_0.8", `plot1' ytitle("Thousands of dollars", size(medlarge)) || connected VSLY QALE if scen=="base_1.25", `plot2' || connected VSLY QALE if scen=="base_1.5", `plot3' || connected VSLY QALE if scen=="bequest_1.25", `plot4' `graph_options'
graph export "$Longevity/results/figures/robustness_mc_vsly_age70.pdf", replace as(pdf)

* VSI per QALY at age 70
use "`vsiy'", clear

collapse (mean) VSIY, by(state_sick QALE_sick scen) fast
append using "`vsl_70'"

sort scen QALE_sick
format VSIY %12.0fc
label var QALE_sick "Life expectancy when ill (QALYs)"

graph twoway connected VSIY QALE_sick if scen=="base_0.8", `plot1' ytitle("Thousands of dollars", size(medlarge)) || connected VSIY QALE_sick if scen=="base_1.25", `plot2' || connected VSIY QALE_sick if scen=="base_1.5", `plot3' || connected VSIY QALE_sick if scen=="bequest_1.25", `plot4' `graph_options' text(189 0.1 "(death)", place(e))
graph export "$Longevity/results/figures/robustness_mc_vsiy_age70.pdf", replace as(pdf)


***********************************
* Second set of robustness figures: set quality of life = 1 and r = 0.03
* Note: Here, everything is normalized by life expectancy rather than by quality-adjusted life expectancy
***********************************
local graph_options `"legend(label(1 "Baseline") label(2 "Omit quality of life") label(3 "No financial shocks") position(6) cols(4) region(lstyle(solid))) xlab(,nogrid) ylab(,angle(horizontal) gstyle(default))"'

* cons/vsl
use "`cons_vsl'", clear

graph twoway line c_oopmd age if scen=="base_1.25", `plot2' ytitle("Thousands of dollars", size(medlarge)) || line c_oopmd age if scen=="robustness_q_1.25", `plot3'  || line c_oopmd age if scen=="robustness_wealth_1.25", `plot1' `graph_options' xtitle("Age", size(medlarge))
graph export "$Longevity/results/figures/robustness2_consumption.pdf", replace as(pdf)

graph twoway line VSL_oopmd age if scen=="base_1.25", `plot2' ytitle("Thousands of dollars", size(medlarge)) || line VSL_oopmd age if scen=="robustness_q_1.25", `plot3' || line VSL_oopmd age if scen=="robustness_wealth_1.25", `plot1' `graph_options' xtitle("Age", size(medlarge)) ylabel(0(1000)7000, angle(horizontal))
graph export "$Longevity/results/figures/robustness2_vsl.pdf", replace as(pdf)


* VSL per life-year at age 70
use "`simulations'" if age==70, clear
collapse (mean) VSL VSLY VSLY_LE, by(state LE QALE scen) fast

sort scen LE
label var LE "Life expectancy at age 70 (years)"
sort scen QALE
label var QALE "Life expectancy at age 70 (QALYs)"
graph twoway connected VSLY QALE if scen=="base_1.25", `plot2' || connected VSLY QALE if scen=="robustness_q_1.25", `plot3'  || connected VSLY QALE if scen=="robustness_wealth_1.25", `plot1' ytitle("Thousands of dollars", size(medlarge)) `graph_options'
graph export "$Longevity/results/figures/robustness2_mc_vsly_age70.pdf", replace as(pdf)

* VSI per QALY at age 70
use "`vsiy'", clear

collapse (mean) VSIY, by(state_sick QALE_sick scen) fast
append using "`vsl_70'"

format VSIY %12.0fc
sort scen QALE_sick
label var QALE_sick "Life expectancy when ill (QALYs)"

graph twoway connected VSIY QALE_sick if scen=="base_1.25", `plot2' || connected VSIY QALE_sick if scen=="robustness_q_1.25", ytitle("Thousands of dollars") `plot3' || connected VSIY QALE_sick if scen=="robustness_wealth_1.25", `plot1' `graph_options' text(136.5 0.1 "(death)", place(e))
graph export "$Longevity/results/figures/robustness2_mc_vsiy_age70.pdf", replace as(pdf)

******************************
* Other supporting analysis
******************************

* Figure \ref{F - MC VSL variance - state1} illustrates VSL over the life cycle for the subset (44\%) of individuals who were in health state 1 at age 50. 
insheet using "$Longevity/results/intermediate/base_1.25/wealth_nsims.csv", clear
assert abs(pct-44.47)<0.01 if health_state==1


* "At age 50, VSL ranges from \$0.8 million for individuals in poor health to \$6.8 million for those in excellent health"
use "$Longevity/results/intermediate/base_1.25/simulations_processed_allstates.dta", clear
keep if age==50
summ VSL
assert abs(r(min) - 800000) < 25000
assert abs(r(max) - 6800000) < 250000
** EOF




